from django.test import SimpleTestCase

from tailwindcss.templatetags.tailwindcss import tailwind


class TailwindCSSTestCase(SimpleTestCase):
    def test_init_tailwindcss_text(self):
        css_text = tailwind.css
        self.assertIsNotNone(css_text)


from django.apps import AppConfig
from django.utils.autoreload import file_changed

from . import signals


class TailwindcssConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'tailwindcss'

    def ready(self):
        file_changed.connect(signals.refresh_tailwindcss, dispatch_uid='tailwindcss_file_changed')



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="django-tailwindcss",
    version="0.2.2",
    author="Veoco",
    author_email="one@nomox.cn",
    description="Develop with Tailwind CSS in Django flavour.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/veoco/django-tailwindcss",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)


import re
import subprocess

from django import template
from django.conf import settings
from django.utils.html import format_html


class TailwindCSS:
    def __init__(self):
        self.css = None
        self._css_rule = re.compile(r"/.*}")
        self._cli_file = settings.TAILWINDCSS_CLI_FILE
        self._config_file = settings.TAILWINDCSS_CONFIG_FILE

        self.refresh()

    def refresh(self):
        task = subprocess.run(
            [self._cli_file, "-m", "-c", self._config_file],
            capture_output=True,
            text=True,
            check=True,
        )
        self.css = self._css_rule.search(task.stdout).group()


tailwind = TailwindCSS()

register = template.Library()


@register.simple_tag
def tailwindcss():
    css = format_html("<style>{}</style>", tailwind.css)
    return css
